// src/server.ts
import {
  createRequestHandler as createRemixRequestHandler
} from "@remix-run/node";

// src/adapters/api-gateway-v1.ts
import { readableStreamToString } from "@remix-run/node";
import { URLSearchParams } from "url";

// src/binaryTypes.ts
var binaryTypes = [
  "application/octet-stream",
  // Docs
  "application/epub+zip",
  "application/msword",
  "application/pdf",
  "application/rtf",
  "application/vnd.amazon.ebook",
  "application/vnd.ms-excel",
  "application/vnd.ms-powerpoint",
  "application/vnd.openxmlformats-officedocument.presentationml.presentation",
  "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
  "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
  // Fonts
  "font/otf",
  "font/woff",
  "font/woff2",
  // Images
  "image/bmp",
  "image/gif",
  "image/jpeg",
  "image/png",
  "image/tiff",
  "image/vnd.microsoft.icon",
  "image/webp",
  // Audio
  "audio/3gpp",
  "audio/aac",
  "audio/basic",
  "audio/mpeg",
  "audio/ogg",
  "audio/wavaudio/webm",
  "audio/x-aiff",
  "audio/x-midi",
  "audio/x-wav",
  // Video
  "video/3gpp",
  "video/mp2t",
  "video/mpeg",
  "video/ogg",
  "video/quicktime",
  "video/webm",
  "video/x-msvideo",
  // Archives
  "application/java-archive",
  "application/vnd.apple.installer+xml",
  "application/x-7z-compressed",
  "application/x-apple-diskimage",
  "application/x-bzip",
  "application/x-bzip2",
  "application/x-gzip",
  "application/x-java-archive",
  "application/x-rar-compressed",
  "application/x-tar",
  "application/x-zip",
  "application/zip"
];
function isBinaryType(contentType) {
  if (!contentType)
    return false;
  return binaryTypes.some((t) => contentType.includes(t));
}

// src/adapters/api-gateway-v1.ts
function createRemixRequest(event) {
  const host = event.headers["x-forwarded-host"] || event.headers.Host;
  const scheme = event.headers["x-forwarded-proto"] || "http";
  const rawQueryString = new URLSearchParams(event.queryStringParameters).toString();
  const search = rawQueryString.length > 0 ? `?${rawQueryString}` : "";
  const url = new URL(event.path + search, `${scheme}://${host}`);
  const isFormData = event.headers["content-type"]?.includes(
    "multipart/form-data"
  );
  return new Request(url.href, {
    method: event.requestContext.httpMethod,
    headers: createRemixHeaders(event.headers),
    body: event.body && event.isBase64Encoded ? isFormData ? Buffer.from(event.body, "base64") : Buffer.from(event.body, "base64").toString() : event.body || void 0
  });
}
function createRemixHeaders(requestHeaders) {
  const headers = new Headers();
  for (const [header, value] of Object.entries(requestHeaders)) {
    if (value) {
      headers.append(header, value);
    }
  }
  return headers;
}
async function sendRemixResponse(nodeResponse) {
  const contentType = nodeResponse.headers.get("Content-Type");
  const isBase64Encoded = isBinaryType(contentType);
  let body;
  if (nodeResponse.body) {
    if (isBase64Encoded) {
      body = await readableStreamToString(nodeResponse.body, "base64");
    } else {
      body = await nodeResponse.text();
    }
  }
  return {
    statusCode: nodeResponse.status,
    headers: Object.fromEntries(nodeResponse.headers.entries()),
    body: body || "",
    isBase64Encoded
  };
}
var apiGatewayV1Adapter = {
  createRemixRequest,
  sendRemixResponse
};

// src/adapters/api-gateway-v2.ts
import { readableStreamToString as readableStreamToString2 } from "@remix-run/node";
function createRemixRequest2(event) {
  const host = event.headers["x-forwarded-host"] || event.headers.host;
  const search = event.rawQueryString.length ? `?${event.rawQueryString}` : "";
  const scheme = event.headers["x-forwarded-proto"] || "http";
  const url = new URL(event.rawPath + search, `${scheme}://${host}`);
  const isFormData = event.headers["content-type"]?.includes(
    "multipart/form-data"
  );
  return new Request(url.href, {
    method: event.requestContext.http.method,
    headers: createRemixHeaders2(event.headers, event.cookies),
    body: event.body && event.isBase64Encoded ? isFormData ? Buffer.from(event.body, "base64") : Buffer.from(event.body, "base64").toString() : event.body
  });
}
function createRemixHeaders2(requestHeaders, requestCookies) {
  const headers = new Headers();
  for (const [header, value] of Object.entries(requestHeaders)) {
    if (value) {
      headers.append(header, value);
    }
  }
  if (requestCookies) {
    headers.append("Cookie", requestCookies.join("; "));
  }
  return headers;
}
async function sendRemixResponse2(nodeResponse) {
  const cookies = [];
  for (const [key, values] of Object.entries(nodeResponse.headers.raw())) {
    if (key.toLowerCase() === "set-cookie") {
      for (const value of values) {
        cookies.push(value);
      }
    }
  }
  if (cookies.length) {
    nodeResponse.headers.delete("Set-Cookie");
  }
  const contentType = nodeResponse.headers.get("Content-Type");
  const isBase64Encoded = isBinaryType(contentType);
  let body;
  if (nodeResponse.body) {
    if (isBase64Encoded) {
      body = await readableStreamToString2(nodeResponse.body, "base64");
    } else {
      body = await nodeResponse.text();
    }
  }
  return {
    statusCode: nodeResponse.status,
    headers: Object.fromEntries(nodeResponse.headers.entries()),
    cookies,
    body,
    isBase64Encoded
  };
}
var apiGatewayV2Adapter = {
  createRemixRequest: createRemixRequest2,
  sendRemixResponse: sendRemixResponse2
};

// src/adapters/application-load-balancer.ts
import { readableStreamToString as readableStreamToString3 } from "@remix-run/node";
import { URLSearchParams as URLSearchParams2 } from "url";
function createRemixRequest3(event) {
  const headers = event?.headers || {};
  const host = headers["x-forwarded-host"] || headers.Host;
  const scheme = headers["x-forwarded-proto"] || "http";
  const rawQueryString = new URLSearchParams2(event.queryStringParameters).toString();
  const search = rawQueryString.length > 0 ? `?${rawQueryString}` : "";
  const url = new URL(event.path + search, `${scheme}://${host}`);
  const isFormData = headers["content-type"]?.includes(
    "multipart/form-data"
  );
  return new Request(url.href, {
    method: event.httpMethod,
    headers: createRemixHeaders3(headers),
    body: event.body && event.isBase64Encoded ? isFormData ? Buffer.from(event.body, "base64") : Buffer.from(event.body, "base64").toString() : event.body || void 0
  });
}
function createRemixHeaders3(requestHeaders) {
  const headers = new Headers();
  for (const [header, value] of Object.entries(requestHeaders)) {
    if (value) {
      headers.append(header, value);
    }
  }
  return headers;
}
async function sendRemixResponse3(nodeResponse) {
  const contentType = nodeResponse.headers.get("Content-Type");
  const isBase64Encoded = isBinaryType(contentType);
  let body;
  if (nodeResponse.body) {
    if (isBase64Encoded) {
      body = await readableStreamToString3(nodeResponse.body, "base64");
    } else {
      body = await nodeResponse.text();
    }
  }
  return {
    statusCode: nodeResponse.status,
    headers: Object.fromEntries(nodeResponse.headers.entries()),
    body: body || "",
    isBase64Encoded
  };
}
var applicationLoadBalancerAdapter = {
  createRemixRequest: createRemixRequest3,
  sendRemixResponse: sendRemixResponse3
};

// src/adapters/index.ts
var createRemixAdapter = (awsProxy) => {
  switch (awsProxy) {
    case "APIGatewayV1" /* APIGatewayV1 */:
      return apiGatewayV1Adapter;
    case "APIGatewayV2" /* APIGatewayV2 */:
      return apiGatewayV2Adapter;
    case "ALB" /* ALB */:
      return applicationLoadBalancerAdapter;
  }
};

// src/server.ts
var AWSProxy = /* @__PURE__ */ ((AWSProxy2) => {
  AWSProxy2["APIGatewayV1"] = "APIGatewayV1";
  AWSProxy2["APIGatewayV2"] = "APIGatewayV2";
  AWSProxy2["ALB"] = "ALB";
  return AWSProxy2;
})(AWSProxy || {});
function createRequestHandler({
  build: build2,
  getLoadContext,
  mode = process.env.NODE_ENV,
  awsProxy = "APIGatewayV2" /* APIGatewayV2 */
}) {
  const handleRequest = createRemixRequestHandler(build2, mode);
  return async (event) => {
    const awsAdapter = createRemixAdapter(awsProxy);
    const request = awsAdapter.createRemixRequest(event);
    const loadContext = getLoadContext?.(event);
    const response = await handleRequest(request, loadContext);
    return awsAdapter.sendRemixResponse(response);
  };
}

// src/vite-preset.ts
import * as esbuild from "esbuild";
import {
  cpSync,
  readFileSync,
  rmSync,
  writeFileSync
} from "fs";
import { join } from "path";
var defaultConfig = {
  awsProxy: "APIGatewayV2" /* APIGatewayV2 */,
  build: {
    logLevel: "info",
    entryPoints: [
      "build/server.js"
    ],
    bundle: true,
    sourcemap: false,
    platform: "node",
    outfile: "build/server/index.js",
    // will replace remix server build file
    allowOverwrite: true,
    write: true
  }
};
var copyGenericHandler = (remixUserConfig, config) => {
  const buildDirectory = remixUserConfig.buildDirectory ?? "build";
  const templateServerFile = join(__dirname, "server.js");
  const destinationServerFile = join(buildDirectory, "server.js");
  console.log("\u{1F4CB} Copying generic handler to:", buildDirectory);
  cpSync(templateServerFile, destinationServerFile);
  if (config.awsProxy) {
    let serverFileWithConfig = readFileSync(destinationServerFile, "utf-8");
    serverFileWithConfig = serverFileWithConfig.replace(
      /awsProxy: .+/,
      `awsProxy: '${config.awsProxy}'`
    );
    writeFileSync(destinationServerFile, serverFileWithConfig, "utf8");
  }
};
var cleanupHandler = (remixUserConfig) => {
  rmSync(
    join(remixUserConfig.buildDirectory ?? "build", "server.js")
  );
};
var buildEndHandler = (config) => async ({
  remixConfig
}) => {
  console.log("\u{1F477} Building for AWS...");
  const mergedConfig = {
    ...defaultConfig,
    ...config,
    build: {
      ...defaultConfig.build,
      ...config.build
    }
  };
  const { build: build2 } = mergedConfig;
  if (!config?.build?.entryPoints) {
    copyGenericHandler(remixConfig, mergedConfig);
  }
  try {
    await esbuild.build(build2);
    console.log("\u2705 Build for AWS successful!");
  } catch (error) {
    console.error("\u{1F6AB} Build for AWS failed:", error);
    process.exit(1);
  } finally {
    console.log("\u{1F9F9} Cleaning up...");
    cleanupHandler(remixConfig);
    console.log("\u{1F9F9} Cleaned up!");
  }
};
function awsPreset(config = {}) {
  return {
    name: "aws-preset",
    remixConfig: () => ({
      buildEnd: buildEndHandler(config)
    })
  };
}
export {
  AWSProxy,
  awsPreset,
  createRequestHandler
};
//# sourceMappingURL=index.mjs.map